
# Slot: objects

All of the objects that are part of the model. This includes terms as well as publications and database objects like gene. This is not strictly part of the data managed by the model, it is for convenience, and should be refreshed from outside.

URI: [gocam:model__objects](https://w3id.org/gocam/model__objects)


## Domain and Range

None &#8594;  <sub>0..\*</sub> [Object](Object.md)

## Parents


## Children


## Used by

 * [Model](Model.md)
